==> 3.0.2.2.zip: geoip/copy_this/modules/d3/d3geoip/views/admin/de/d3_geoip_lang.php <==
<?php
/**
 * This Software is the property of Data Development and is protected
 * by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * http://www.shopmodule.com
 *
 * @copyright (C) D3 Data Development (Inh. Thomas Dartsch)
 * @author    D3 Data Development - Daniel Seifert <ds@shopmodule.com>
 * @link      http://www.oxidmodule.com
 */

$sLangName  = 'Deutsch';
$iLangNr    = 0;
// -------------------------------
// RESOURCE IDENTITFIER = STRING
// -------------------------------
$aLang = array(
    'charset'                                       => 'ISO-8859-15',
    'd3mxgeoip'                                     => "<i class='fa fa-globe'></i> GeoIP",
    'd3mxgeoip_settings'                            => 'Einstellungen',
    'd3tbclgeoip_settings_main'                     => 'Grundeinstellungen',
    'tbclcountry_geoip'                             => 'GeoIP-Kundenumleitungen',

    'D3_GEOIP_TRANSL'                               => 'GeoIP-Kundenumleitungen',

    'D3_GEOIP_SET_DEBUG_DESC'                       => 'Mit aktiviertem Debug-Modus wird im Frontend die aktuelle '.
        'IP-Adresse des Shopbesuchers gezeigt. Beachten Sie, dass Umleitungen, die auf Weiterleitungen basieren, dann '.
        'nicht ausgefhrt werden knnen.',
    'D3_GEOIP_SET_OPTIONS'                          => 'Optionen',
    'D3_GEOIP_SET_OPTIONS_CHANGESHOP'               => 'Mandant wechseln, wenn eingestellt (nur EE)',
    'D3_GEOIP_SET_OPTIONS_CHANGECURR'               => 'Whrung wechseln, wenn eingestellt',
    'D3_GEOIP_SET_OPTIONS_CHANGELANG'               => 'Sprache wechseln, wenn eingestellt',
    'D3_GEOIP_SET_OPTIONS_CHANGEURL'                => 'URL wechseln, wenn eingestellt',
    'D3_GEOIP_SET_OPTIONS_NOCOUNTRY'                => 'Shop verwendet die Einstellung dieses Landes, wenn IP nicht '.
        'zuzuordnen ist',
    'D3_GEOIP_SET_IP'                               => 'IP-Einstellungen',
    'D3_GEOIP_SET_IP_TESTIP'                        => 'statt Kunden-IP immer diese IP-Adresse verwenden',
    'D3_GEOIP_SET_IP_TESTCOUNTRY'                   => 'statt Kunden-IP immer eine IP-Adresse dieses Landes verwenden',
    'D3_GEOIP_SET_IP_TESTCOUNTRY_INACTIVE'          => '(inaktiv)',
    'D3_GEOIP_SET_IP_CHECKIP'                       => 'diese IP-Adresse prfen',
    'D3_GEOIP_SET_IP_CHECKIP_NOTSET'                => 'IP nicht zugewiesen oder Land nicht aktiv',
    'D3_GENERAL_GEOIP_SAVE'                         => 'Speichern',

    'D3_GEOIP_SELSHOP'                              => 'zustndiger Shop',
    'D3_GEOIP_SELLANG'                              => 'vorgewhlte Sprache',
    'D3_GEOIP_SELCUR'                               => 'vorgewhlte Whrung',
    'D3_GEOIP_CUSTSELSHOP'                          => ' - vom Kunden gewhlter Shop - ',
    'D3_GEOIP_CUSTSELLANG'                          => ' - vom Kunden gewhlte Sprache - ',
    'D3_GEOIP_CUSTSELCUR'                           => ' - vom Kunden gewhlte Whrung - ',
    'D3_GEOIP_OR'                                   => 'oder',
    'D3_GEOIP_DISABLED'                             => '(deaktiviert)',
    'D3_GEOIP_SELURL'                               => 'zu wechselnde URL',
    'D3_GEOIP_SELURL_DESC'                          => 'Sobald im URL-Feld eine Eingabe vorhanden ist, wird bei '.
        'passenden Kunden versucht, zur hinterlegten URL zu wechseln. Mchten Sie den Mandanten, die Whrung und / '.
        'oder die Sprache einstellen, entfernen Sie die URL.<br><br>Aktivieren / deaktivieren Sie den URL-Wechsel '.
        'zustzlich in den Modul-Grundeinstellungen.',

    'D3_GEOIP_METADATA_TITLE'                       => 'D GeoIP Vorauswahl',
    'D3_GEOIP_METADATA_DESC'                        => 'Begren Sie Ihre Kunden in seiner Landessprache.',

    'D3_GEOIP_UPDATE_ITEMINSTALL'                   => 'Die umfangreiche IP-Liste kann leider nicht ber die '.
        'automatische Installation eingebunden werden. Bitte installieren Sie diese manuell. '.PHP_EOL.PHP_EOL.
        'Die erforderlichen Daten finden Sie im Installationspaket des Moduls unter '.
        '"setup+doku/geoip-Data_IPv4_*.sql" ("setup+doku/geoip-Data_IPv6_*.sql" fr IPv6-Adressen) oder als '.
        'handlichere SQL-Dateien unter "setup+doku/geoip_data_parts/". '.PHP_EOL.PHP_EOL.
        'Sie bentigen entweder die Komplettdateien oder die Sammlung kleinerer Daten. Fhren Sie die SQL-Datei(en) '.
        'bitte in Ihrer Datenbank aus.',
);

==> 3.1.0.0.zip: geoip/copy_this/modules/d3/d3geoip/views/admin/de/d3_geoip_lang.php <==
<?php
/**
 * This Software is the property of Data Development and is protected
 * by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * http://www.shopmodule.com
 *
 * @copyright (C) D3 Data Development (Inh. Thomas Dartsch)
 * @author    D3 Data Development - Daniel Seifert <ds@shopmodule.com>
 * @link      http://www.oxidmodule.com
 */

$sLangName  = 'Deutsch';
$iLangNr    = 0;
// -------------------------------
// RESOURCE IDENTITFIER = STRING
// -------------------------------
$aLang = array(
    'charset'                                       => 'ISO-8859-15',
    'd3mxgeoip'                                     => "<i class='fa fa-globe'></i> GeoIP",
    'd3mxgeoip_settings'                            => 'Einstellungen',
    'd3tbclgeoip_settings_main'                     => 'Grundeinstellungen',
    'tbclcountry_geoip'                             => 'GeoIP-Kundenumleitungen',

    'D3_GEOIP_TRANSL'                               => 'GeoIP-Kundenumleitungen',

    'D3_GEOIP_SET_DEBUG_DESC'                       => 'Mit aktiviertem Debug-Modus wird im Frontend die aktuelle '.
        'IP-Adresse des Shopbesuchers gezeigt. Beachten Sie, dass Umleitungen, die auf Weiterleitungen basieren, dann '.
        'nicht ausgefhrt werden knnen.',
    'D3_GEOIP_SET_OPTIONS'                          => 'Optionen',
    'D3_GEOIP_SET_OPTIONS_CHANGESHOP'               => 'Mandant wechseln, wenn eingestellt (nur EE)',
    'D3_GEOIP_SET_OPTIONS_CHANGECURR'               => 'Whrung wechseln, wenn eingestellt',
    'D3_GEOIP_SET_OPTIONS_CHANGELANG'               => 'Sprache wechseln, wenn eingestellt',
    'D3_GEOIP_SET_OPTIONS_CHANGEURL'                => 'URL wechseln, wenn eingestellt',
    'D3_GEOIP_SET_OPTIONS_NOCOUNTRY'                => 'Shop verwendet die Einstellung dieses Landes, wenn IP nicht '.
        'zuzuordnen ist',
    'D3_GEOIP_SET_IP'                               => 'IP-Einstellungen',
    'D3_GEOIP_SET_IP_TESTIP'                        => 'statt Kunden-IP immer diese IP-Adresse verwenden',
    'D3_GEOIP_SET_IP_TESTCOUNTRY'                   => 'statt Kunden-IP immer eine IP-Adresse dieses Landes verwenden',
    'D3_GEOIP_SET_IP_TESTCOUNTRY_INACTIVE'          => '(inaktiv)',
    'D3_GEOIP_SET_IP_CHECKIP'                       => 'diese IP-Adresse prfen',
    'D3_GEOIP_SET_IP_CHECKIP_NOTSET'                => 'IP nicht zugewiesen oder Land nicht aktiv',
    'D3_GENERAL_GEOIP_SAVE'                         => 'Speichern',

    'D3_GEOIP_SELSHOP'                              => 'zustndiger Shop',
    'D3_GEOIP_SELLANG'                              => 'vorgewhlte Sprache',
    'D3_GEOIP_SELCUR'                               => 'vorgewhlte Whrung',
    'D3_GEOIP_CUSTSELSHOP'                          => ' - vom Kunden gewhlter Shop - ',
    'D3_GEOIP_CUSTSELLANG'                          => ' - vom Kunden gewhlte Sprache - ',
    'D3_GEOIP_CUSTSELCUR'                           => ' - vom Kunden gewhlte Whrung - ',
    'D3_GEOIP_OR'                                   => 'oder',
    'D3_GEOIP_DISABLED'                             => '(deaktiviert)',
    'D3_GEOIP_SELURL'                               => 'zu wechselnde URL',
    'D3_GEOIP_SELURL_DESC'                          => 'Sobald im URL-Feld eine Eingabe vorhanden ist, wird bei '.
        'passenden Kunden versucht, zur hinterlegten URL zu wechseln. Mchten Sie den Mandanten, die Whrung und / '.
        'oder die Sprache einstellen, entfernen Sie die URL.<br><br>Aktivieren / deaktivieren Sie den URL-Wechsel '.
        'zustzlich in den Modul-Grundeinstellungen.',

    'D3_GEOIP_METADATA_TITLE'                       => 'D GeoIP Vorauswahl',
    'D3_GEOIP_METADATA_DESC'                        => 'Begren Sie Ihre Kunden in seiner Landessprache.',

    'D3_GEOIP_UPDATE_ITEMINSTALL'                   => 'Die umfangreiche IP-Liste kann leider nicht ber die '.
        'automatische Installation eingebunden werden. Bitte installieren Sie diese manuell. '.PHP_EOL.PHP_EOL.
        'Laden Sie bitte die aktuellen CSV-Daten des Anbieters Maxmind. In "setup+doku/importCSVtoMySQL" des Modulpaketes finden Sie weitere Informationen und die erforderlichen Datenbank-Befehle, um die ntigen Daten zu generieren.'.PHP_EOL.PHP_EOL.
        'Alternativ finden Sie die erforderlichen Daten im Installationspaket des Moduls unter "setup+doku/geoip-data_*". '.PHP_EOL.PHP_EOL.
        'Fhren Sie die SQL-Datei(en) bitte in Ihrer Datenbank aus.',
);
